@@ -1,24 +1,33 @@
 import itertools
+from collections import defaultdict
 from enum import Enum, unique
-from typing import Dict, List, Optional, Tuple, Union
+from typing import Any, Dict, Iterable, List, Optional, Tuple, Union
 
+import pandas as pd
 import pyarrow as pa
 import vaex
 from vaex.dataframe import DataFrame
 
 from dataquality.exceptions import GalileoException
-from dataquality.loggers.data_logger.base_data_logger import BaseGalileoDataLogger
+from dataquality.loggers.data_logger.base_data_logger import (
+    ITER_CHUNK_SIZE,
+    BaseGalileoDataLogger,
+    DataSet,
+    MetasType,
+    MetaType,
+)
 from dataquality.loggers.logger_config.text_ner import text_ner_logger_config
 from dataquality.schemas import __data_schema_version__
 from dataquality.schemas.dataframe import BaseLoggerInOutFrames
 from dataquality.schemas.ner import NERColumns as NERCols
 from dataquality.schemas.ner import TaggingSchema
 from dataquality.schemas.split import Split
+from dataquality.utils.vaex import rename_df
 
 
 @unique
 class GalileoDataLoggerAttributes(str, Enum):
-    text = "text"
+    texts = "texts"
     text_token_indices = "text_token_indices"
     text_token_indices_flat = "text_token_indices_flat"
     gold_spans = "gold_spans"
@@ -65,12 +74,12 @@ class TextNERDataLogger(BaseGalileoDataLogger):
     .. code-block:: python
 
         labels = ["B-PER", "I-PER", "B-LOC", "I-LOC", "O"]
-        dataquality.set_labels_for_run(labels = labels)
+        dq.set_labels_for_run(labels = labels)
 
         # One of (IOB2, BIO, IOB, BILOU, BILOES)
-        dataquality.set_tagging_schema(tagging_schema: str = "BIO")
+        dq.set_tagging_schema(tagging_schema: str = "BIO")
 
-        text: List[str] = [
+        texts: List[str] = [
             "The president is Joe Biden",
             "Joe Biden addressed the United States on Monday"
         ]
@@ -88,11 +97,12 @@ class TextNERDataLogger(BaseGalileoDataLogger):
         text_token_indices: [[(0, 3), (4, 13), (14, 16), (17, 20), (21, 27), (21, 27)],
                 [...]]
         ids: List[int] = [0, 1]
+        meta = {"sample_quality": [5.3, 1.1]}
         split = "training"
 
-        dataquality.log_input_data(
-            text=text, text_token_indices=text_token_indices,
-            gold_spans=gold_spans, ids=ids, split=split
+        dq.log_data_samples(
+            texts=texts, text_token_indices=text_token_indices,
+            gold_spans=gold_spans, meta=meta, ids=ids, split=split
         )
     """
 
@@ -103,16 +113,16 @@ class TextNERDataLogger(BaseGalileoDataLogger):
 
     def __init__(
         self,
-        text: List[str] = None,
+        texts: List[str] = None,
         text_token_indices: List[List[Tuple[int, int]]] = None,
         gold_spans: List[List[Dict]] = None,
         ids: List[int] = None,
         split: str = None,
-        meta: Optional[Dict[str, List[Union[str, float, int]]]] = None,
+        meta: MetasType = None,
     ) -> None:
         """Create data logger.
 
-        :param text: The raw text inputs for model training. List[str]
+        :param texts: The raw text inputs for model training. List[str]
         :param text_token_indices: Token boundaries of text. List[Tuple(int, int)].
         Used to convert the gold_spans into token level spans internally.
         t[0] indicates the start index of the span and t[1] is the end index (exclusive)
@@ -124,7 +134,7 @@ class TextNERDataLogger(BaseGalileoDataLogger):
         super().__init__(meta)
         # Need to compare to None because they may be np arrays which cannot be
         # evaluated with bool directly
-        self.text = text if text is not None else []
+        self.texts = texts if texts is not None else []
         self.text_token_indices = (
             text_token_indices if text_token_indices is not None else []
         )
@@ -141,6 +151,204 @@ class TextNERDataLogger(BaseGalileoDataLogger):
         """
         return GalileoDataLoggerAttributes.get_valid()
 
+    def log_data_samples(
+        self,
+        *,
+        texts: List[str],
+        ids: List[int],
+        text_token_indices: List[List[Tuple[int, int]]] = None,
+        gold_spans: List[List[Dict]] = None,
+        split: Optional[Split] = None,
+        meta: Optional[MetasType] = None,
+        **kwargs: Any,  # For typing
+    ) -> None:
+        """Log input samples for text classification
+
+        :param texts: List[str] text samples
+        :param ids: List[int,str] IDs for each text sample
+        :param text_token_indices: List[List[Tuple(int, int)]]. Token boundaries of each
+            text sample, 1 list per sample.
+            Used to convert the gold_spans into token level spans internally.
+            t[0] indicates the start index of the span and t[1] is the end index
+            (exclusive). Required if split is not inference
+        :param gold_spans: List[List[Dict]] The model-level gold spans over the char
+            index for each text sample. 1 List[Dict] per text sample.
+            "start", "end", "label" are the required keys
+            Required if split is not inference
+        :param ids: Optional unique indexes for each record. If not provided, will
+        :param split: train/test/validation/inference. Can be set here or via
+            dq.set_split
+        :param meta: Dict[str, List[str, int, float]]. Metadata for each text sample
+            Format is the {"metadata_field_name": [metdata value per sample]}
+        """
+        self.validate_kwargs(kwargs)
+        self.texts = texts
+        self.ids = ids
+        self.split = split
+        self.text_token_indices = (
+            text_token_indices if text_token_indices is not None else []
+        )
+        self.gold_spans = gold_spans if gold_spans is not None else []
+        self.meta = meta or {}
+        self.log()
+
+    def log_data_sample(
+        self,
+        *,
+        text: str,
+        id: int,
+        text_token_indices: List[Tuple[int, int]] = None,
+        gold_spans: List[Dict] = None,
+        split: Optional[Split] = None,
+        meta: Optional[MetaType] = None,
+        **kwargs: Any,
+    ) -> None:
+        """
+        Log a single input sample for text classification
+
+        :param text: str the text sample
+        :param id: The sample ID
+        :param text_token_indices: List[Tuple(int, int)]. Token boundaries of the
+            text sample. Used to convert gold_spans into token level spans internally.
+            t[0] indicates the start index of the span and t[1] is the end index
+            (exclusive). Required if split is not inference
+        :param gold_spans: List[Dict] The model-level gold spans over the char
+            index of the text sample. "start", "end", "label" are the required keys
+            Required if split is not inference
+        :param split: train/test/validation/inference. Can be set here or via
+            dq.set_split
+        :param meta: Dict[str, Union[str, int, float]]. Metadata for the text sample
+            Format is the {"metadata_field_name": metadata_field_value}
+        """
+        self.validate_kwargs(kwargs)
+        self.texts = [text]
+        self.ids = [id]
+        self.split = split
+        self.text_token_indices = (
+            [text_token_indices] if text_token_indices is not None else []
+        )
+        self.gold_spans = [gold_spans] if gold_spans is not None else []
+        self.meta = {i: [meta[i]] for i in meta} if meta else {}
+        self.log()
+
+    def log_dataset(
+        self,
+        dataset: DataSet,
+        *,
+        text: Union[str, int] = "text",
+        id: Union[str, int] = "id",
+        text_token_indices: Union[str, int] = "text_token_indices",
+        gold_spans: Union[str, int] = "gold_spans",
+        split: Optional[Split] = None,
+        meta: Optional[List[Union[str, int]]] = None,
+        **kwargs: Any,
+    ) -> None:
+        """
+        Log a dataset of input samples for NER
+
+        :param dataset: The dataset to log. This can be an python iterable or
+            Pandas/Vaex dataframe. If an iterable, it can be a list of elements that can
+            be indexed into either via int index (tuple/list) or string/key index (dict)
+        :param text: The key/index of the text fields
+        :param id: The key/index of the id fields
+        :param text_token_indices: The key/index of the sample text_token_indices
+        :param gold_spans: The key/index of the sample gold_spans
+        :param split: train/test/validation/inference. Can be set here or via
+            dq.set_split
+        :param meta: List[str, int]: The keys/indexes of each metadata field.
+            Consider a pandas dataframe, this would be the list of columns corresponding
+            to each metadata field to log
+        """
+        self.validate_kwargs(kwargs)
+        self.split = split
+        meta = meta or []
+        column_map = {
+            text: "text",
+            id: "id",
+            gold_spans: "gold_spans",
+            text_token_indices: "text_token_indices",
+        }
+        if isinstance(dataset, pd.DataFrame):
+            dataset = dataset.rename(columns=column_map)
+            self._log_df(dataset, meta)
+        elif isinstance(dataset, DataFrame):
+            for chunk in range(0, len(dataset), ITER_CHUNK_SIZE):
+                chunk_df = dataset[chunk : chunk + ITER_CHUNK_SIZE]
+                chunk_df = rename_df(chunk_df, column_map)
+                self._log_df(chunk_df, meta)
+        elif isinstance(dataset, Iterable):
+            self._log_iterator(
+                dataset,
+                text,
+                id,
+                text_token_indices,
+                gold_spans,
+                meta,
+                split,
+            )
+        else:
+            raise GalileoException(
+                f"Dataset must be one of pandas, vaex, or Iterable, "
+                f"but got {type(dataset)}"
+            )
+
+    def _log_iterator(
+        self,
+        dataset: Iterable,
+        text: Union[str, int],
+        id: Union[str, int],
+        text_token_indices: Union[str, int],
+        gold_spans: Union[str, int],
+        meta: List[Union[str, int]],
+        split: Optional[Split] = None,
+    ) -> None:
+        batches = defaultdict(list)
+        metas = defaultdict(list)
+        for chunk in dataset:
+            batches["text"].append(chunk[text])
+            batches["gold_spans"].append(chunk[gold_spans])
+            batches["text_token_indices"].append(chunk[text_token_indices])
+            batches["id"].append(chunk[id])
+
+            for meta_col in meta:
+                metas[meta_col].append(self._convert_tensor_to_py(chunk[meta_col]))
+
+            if len(batches["text"]) >= ITER_CHUNK_SIZE:
+                self._log_dict(batches, metas, split)
+                batches.clear()
+                metas.clear()
+
+        # in case there are any left
+        if batches:
+            self._log_dict(batches, metas, split)
+
+    def _log_dict(
+        self,
+        d: Dict,
+        meta: Dict,
+        split: Optional[Split] = None,
+    ) -> None:
+        self.log_data_samples(
+            texts=d["text"],
+            ids=d["id"],
+            text_token_indices=d["text_token_indices"],
+            gold_spans=d["gold_spans"],
+            split=split,
+            meta=meta,
+        )
+
+    def _log_df(
+        self, df: Union[pd.DataFrame, DataFrame], meta: List[Union[str, int]]
+    ) -> None:
+        """Helper to log a pandas or vaex df"""
+        self.texts = df["text"].tolist()
+        self.ids = df["id"].tolist()
+        self.text_token_indices = df["text_token_indices"].tolist()
+        self.gold_spans = df["gold_spans"].tolist()
+        for meta_col in meta:
+            self.meta[str(meta_col)] = df[meta_col].tolist()
+        self.log()
+
     def validate(self) -> None:
         """
         Validates that the current config is correct.
@@ -151,7 +359,6 @@ class TextNERDataLogger(BaseGalileoDataLogger):
         :return: None
         """
         super().validate()
-
         assert self.logger_config.labels, (
             "You must set your labels before logging input data. "
             "See dataquality.set_labels_for_run"
@@ -163,7 +370,7 @@ class TextNERDataLogger(BaseGalileoDataLogger):
         )
 
         text_tokenized_len = len(self.text_token_indices)
-        text_len = len(self.text)
+        text_len = len(self.texts)
         gold_span_len = len(self.gold_spans)
         id_len = len(self.ids)
 
@@ -190,7 +397,7 @@ class TextNERDataLogger(BaseGalileoDataLogger):
             )
 
         for sample_id, sample_spans, sample_indices, sample_text in zip(
-            self.ids, self.gold_spans, self.text_token_indices, self.text
+            self.ids, self.gold_spans, self.text_token_indices, self.texts
         ):
             self._validate_sample_spans(sample_spans, sample_indices, sample_text)
 
@@ -306,11 +513,11 @@ class TextNERDataLogger(BaseGalileoDataLogger):
         This function will be used for the sentence level, as that enables the parent's
         `log()` function to behave exactly as expected.
         """
-        df_len = len(self.text)
+        df_len = len(self.texts)
         inp = dict(
             id=self.ids,
             split=[Split(self.split).value] * df_len,
-            text=self.text,
+            text=self.texts,
             text_token_indices=pa.array(self.text_token_indices_flat),
             data_schema_version=[__data_schema_version__] * df_len,
             **self.meta,
@@ -415,11 +622,23 @@ class TextNERDataLogger(BaseGalileoDataLogger):
             "You must set your config labels before calling finish. "
             "See `dataquality.set_labels_for_run`"
         )
-        clean_labels = [
-            i.split("-", maxsplit=1)[1]
-            for i in cls.logger_config.labels
-            if i and cls.is_valid_span_label(i)
-        ]
+
+        clean_labels = []
+        for i in cls.logger_config.labels:
+            if i and cls.is_valid_span_label(i):
+                label = i.split("-", maxsplit=1)[1]
+                assert len(label) != 0, (
+                    "The class names following the tag cannot be empty. For example "
+                    "'B-' is not allowed, but 'B-some_class' is."
+                )
+                clean_labels.append(label)
+
+        assert len(clean_labels) != 0, (
+            f"No valid labels found among {cls.logger_config.labels}. A valid label "
+            f"is one that starts with either B-, I-, L-, E-, S-, or U- according to "
+            f"your particular tagging scheme"
+        )
+
         clean_labels = list(dict.fromkeys(clean_labels))  # Remove dups, keep order
         return clean_labels
 
@@ -431,14 +650,16 @@ class TextNERDataLogger(BaseGalileoDataLogger):
         I = In the sequence
         L/E = Last/Ending character of the sequence
         S/U = Single/Unit element of a sequence
+
+        A valid span label would then start with 'B-' for example.
         """
         return (
-            label.startswith("B")
-            or label.startswith("I")
-            or label.startswith("L")
-            or label.startswith("E")
-            or label.startswith("S")
-            or label.startswith("U")
+            label.startswith("B-")
+            or label.startswith("I-")
+            or label.startswith("L-")
+            or label.startswith("E-")
+            or label.startswith("S-")
+            or label.startswith("U-")
         )
 
     @classmethod
