@@ -1,6 +1,6 @@
 import warnings
 from abc import abstractmethod
-from typing import Any, Dict, List, Optional, Union
+from typing import Dict, List, Optional, Union
 from uuid import uuid4
 
 import numpy as np
@@ -12,21 +12,41 @@ from dataquality.loggers.base_logger import BaseGalileoLogger
 from dataquality.loggers.data_logger import BaseGalileoDataLogger
 from dataquality.schemas.split import Split
 from dataquality.schemas.task_type import TaskType
+from dataquality.utils.stdout_logger import get_stdout_logger
 from dataquality.utils.thread_pool import ThreadPoolManager
 from dataquality.utils.vaex import _save_hdf5_file
 
 
 class BaseGalileoModelLogger(BaseGalileoLogger):
-    def __init__(self, **kwargs: Dict[str, Any]) -> None:
+    def __init__(
+        self,
+        embs: Union[List, np.ndarray] = None,
+        probs: Union[List, np.ndarray] = None,
+        logits: Union[List, np.ndarray] = None,
+        ids: Union[List, np.ndarray] = None,
+        split: str = "",
+        epoch: Optional[int] = None,
+        inference_name: Optional[str] = None,
+    ) -> None:
         super().__init__()
-        self.epoch: Optional[int] = None
-        self.inference_name: Optional[str] = None
+        # Need to compare to None because they may be np arrays which cannot be
+        # evaluated with bool directly
+        self.embs: Union[List, np.ndarray] = embs if embs is not None else []
+        self.logits: Union[List, np.ndarray] = logits if logits is not None else []
+        self.probs: Union[List, np.ndarray] = probs if probs is not None else []
+        self.ids: Union[List, np.ndarray] = ids if ids is not None else []
+        self.epoch = epoch
+        self.split: str = split
+        self.inference_name = inference_name
 
     def _log(self) -> None:
         """Threaded logger target"""
         try:
             self.validate()
         except AssertionError as e:
+            get_stdout_logger().error(
+                "Validation of data failed", split=self.split, epoch=self.epoch
+            )
             raise GalileoException(
                 f"The provided logged data is invalid: {e}"
             ) from None
@@ -37,14 +57,27 @@ class BaseGalileoModelLogger(BaseGalileoLogger):
         try:
             self._log()
         except Exception as e:
+            get_stdout_logger().exception(
+                "Logging of model outputs failed", split=self.split, epoch=self.epoch
+            )
             warnings.warn(f"An issue occurred while logging: {str(e)}")
 
     def log(self) -> None:
         """The top level log function that try/excepts it's child"""
+        # We validate split and epoch before entering the thread because we reference
+        # global variables (cur_split and cur_epoch) that are subject to change
+        # between subsequent threads
+        self.set_split_epoch()
+        get_stdout_logger().info(
+            "Starting logging process from thread", split=self.split, epoch=self.epoch
+        )
         ThreadPoolManager.add_thread(target=self._add_threaded_log)
 
     def write_model_output(self, data: Dict) -> None:
         """Creates an hdf5 file from the data dict"""
+        get_stdout_logger().info(
+            "Writing model output", split=self.split, epoch=self.epoch
+        )
         location = (
             f"{self.LOG_FILE_DIR}/{config.current_project_id}"
             f"/{config.current_run_id}"
@@ -58,11 +91,11 @@ class BaseGalileoModelLogger(BaseGalileoLogger):
             path = f"{location}/{split}/{epoch}"
 
         object_name = f"{str(uuid4()).replace('-', '')[:12]}.hdf5"
+        get_stdout_logger().info("Saving hdf5 file", split=self.split)
         _save_hdf5_file(path, object_name, data)
 
-    @abstractmethod
-    def validate(self) -> None:
-        super().validate()
+    def set_split_epoch(self) -> None:
+        super().set_split_epoch()
         if self.split == Split.inference and self.inference_name is None:
             if self.logger_config.cur_inference_name is not None:
                 self.inference_name = self.logger_config.cur_inference_name
