@@ -11,11 +11,12 @@ from dataquality.loggers.logger_config.text_classification import (
 from dataquality.loggers.model_logger.base_model_logger import BaseGalileoModelLogger
 from dataquality.schemas import __data_schema_version__
 from dataquality.schemas.split import Split
+from dataquality.utils.stdout_logger import get_stdout_logger
 
 
 @unique
 class GalileoModelLoggerAttributes(str, Enum):
-    emb = "emb"
+    embs = "embs"
     probs = "probs"
     logits = "logits"
     ids = "ids"
@@ -33,9 +34,9 @@ class TextClassificationModelLogger(BaseGalileoModelLogger):
     """
     Class for logging model output data of Text Classification models to Galileo.
 
-    * emb: Union[List, np.ndarray, torch.Tensor, tf.Tensor]. The Embeddings per
+    * embs: Union[List, np.ndarray, torch.Tensor, tf.Tensor]. The Embeddings per
     text sample input. Only one embedding vector is allowed per input sample.
-    the `emb` parameter can be formatted either as:
+    the `embs` parameter can be formatted either as:
         * np.ndarray
         * torch.tensor / tf.tensor
         * A list of List[float]
@@ -56,6 +57,18 @@ class TextClassificationModelLogger(BaseGalileoModelLogger):
     IDs for each sample input. This will be used to join them together for analysis
     by Galileo.
     * split: The model training/test/validation split for the samples being logged
+
+    ex:
+    .. code-block:: python
+
+        dq.set_epoch(0)
+        dq.set_split("train")
+
+        embs: np.ndarray = np.random.rand(4, 768)  # 4 samples, embedding dim 768
+        logits: np.ndarray = np.random.rand(4, 3)  # 4 samples, 3 classes
+        ids: List[int] = [0, 1, 2, 3]
+
+        dq.log_model_outputs(embs=embs, logits=logits, ids=ids)
     """
 
     __logger_name__ = "text_classification"
@@ -63,22 +76,23 @@ class TextClassificationModelLogger(BaseGalileoModelLogger):
 
     def __init__(
         self,
-        emb: Union[List, np.ndarray] = None,
+        embs: Union[List, np.ndarray] = None,
         probs: Union[List, np.ndarray] = None,
         logits: Union[List, np.ndarray] = None,
         ids: Union[List, np.ndarray] = None,
         split: str = "",
         epoch: Optional[int] = None,
+        inference_name: Optional[str] = None,
     ) -> None:
-        super().__init__()
-        # Need to compare to None because they may be np arrays which cannot be
-        # evaluated with bool directly
-        self.emb: Union[List, np.ndarray] = emb if emb is not None else []
-        self.logits: Union[List, np.ndarray] = logits if logits is not None else []
-        self.probs: Union[List, np.ndarray] = probs if probs is not None else []
-        self.ids: Union[List, np.ndarray] = ids if ids is not None else []
-        self.split: str = split
-        self.epoch = epoch
+        super().__init__(
+            embs=embs,
+            probs=probs,
+            logits=logits,
+            ids=ids,
+            split=split,
+            epoch=epoch,
+            inference_name=inference_name,
+        )
 
     @staticmethod
     def get_valid_attributes() -> List[str]:
@@ -91,11 +105,10 @@ class TextClassificationModelLogger(BaseGalileoModelLogger):
     def validate(self) -> None:
         """
         Validates that the current config is correct.
-        * emb, probs, and ids must exist and be the same length
+        * embs, probs, and ids must exist and be the same length
         :return:
         """
-        super().validate()
-
+        get_stdout_logger().info("Handling logits and probs", split=self.split)
         if len(self.logits):
             self.logits = self._convert_tensor_ndarray(self.logits, "Prob")
             self.probs = self.convert_logits_to_probs(self.logits)
@@ -104,23 +117,25 @@ class TextClassificationModelLogger(BaseGalileoModelLogger):
             warnings.warn("Usage of probs is deprecated, use logits instead")
             self.probs = self._convert_tensor_ndarray(self.probs, "Prob")
 
-        emb_len = len(self.emb)
-        prob_len = len(self.probs)
-        id_len = len(self.ids)
+        embs_len = len(self.embs)
+        probs_len = len(self.probs)
+        ids_len = len(self.ids)
 
-        self.emb = self._convert_tensor_ndarray(self.emb, "Embedding")
+        get_stdout_logger().info("Converting inputs to numpy arrays", split=self.split)
+        self.embs = self._convert_tensor_ndarray(self.embs, "Embedding")
         self.ids = self._convert_tensor_ndarray(self.ids)
 
-        assert self.emb.ndim == 2, "Only one embedding vector is allowed per input."
+        get_stdout_logger().info("Validating embedding shape", split=self.split)
+        assert self.embs.ndim == 2, "Only one embedding vector is allowed per input."
 
-        assert emb_len and prob_len and id_len, (
+        assert embs_len and probs_len and ids_len, (
             f"All of emb, probs, and ids for your logger must be set, but "
-            f"got emb:{bool(emb_len)}, probs:{bool(prob_len)}, ids:{bool(id_len)}"
+            f"got emb:{bool(embs_len)}, probs:{bool(probs_len)}, ids:{bool(ids_len)}"
         )
 
-        assert emb_len == prob_len == id_len, (
+        assert embs_len == probs_len == ids_len, (
             f"All of emb, probs, and ids for your logger must be the same "
-            f"length, but got (emb, probs, ids) -> ({emb_len},{prob_len}, {id_len})"
+            f"length, but got (emb, probs, ids) -> ({embs_len},{probs_len}, {ids_len})"
         )
 
         # User may manually pass in 'train' instead of 'training' / 'test' vs 'testing'
@@ -128,6 +143,7 @@ class TextClassificationModelLogger(BaseGalileoModelLogger):
         try:
             self.split = Split[self.split].value
         except KeyError:
+            get_stdout_logger().error("Provided a bad split", split=self.split)
             raise AssertionError(
                 f"Split should be one of {Split.get_valid_attributes()} "
                 f"but got {self.split}"
@@ -146,7 +162,7 @@ class TextClassificationModelLogger(BaseGalileoModelLogger):
 
     def _get_data_dict(self) -> Dict[str, Any]:
         data = defaultdict(list)
-        for record_id, prob, emb in zip(self.ids, self.probs, self.emb):
+        for record_id, prob, emb in zip(self.ids, self.probs, self.embs):
             # Handle binary classification by making it 2-class classification
             p = [prob[0], 1 - prob[0]] if len(prob) == 1 else prob
             record = {
